@@ -290,12 +290,12 @@ class SlashClient:
     Parameters
     ----------
 
-    client : commands.Client or commands.Bot
+    client : :class:`commands.Bot` | :class:`commands.AutoShardedBot`
 
     Attributes
     ----------
 
-    client : commands.Client
+    client : :class:`commands.Bot` | :class:`commands.AutoShardedBot`
 
     registered_global_commands : dict
         All registered global commands are cached here
@@ -308,9 +308,10 @@ class SlashClient:
         self.client = HANDLER.client
         self.events = {}
         self.registered_global_commands = []
-        # self.registered_guild_commands = {}
+        self.active_shard_count = 0
         self.is_ready = False
-        self.client.loop.create_task(self._do_ignition())
+        self.client.add_listener(self._on_shard_connect, 'on_shard_connect')
+        self.client.add_listener(self._on_connect, 'on_connect')
     @property
     def commands(self):
         return HANDLER.commands
@@ -657,18 +658,20 @@ class SlashClient:
             await self.delete_guild_command(guild_id, cmd.id)
 
     # Internal use only
-    async def _do_ignition(self):
-        '''# Don't use it'''
-        if isinstance(self.client, AutoShardedClient):
-            for _ in range(self.client.shard_count):
-                shard_id = await self.client.wait_for('shard_connect', timeout=60)
-                self.client._AutoShardedClient__shards[shard_id].ws._discord_parsers['INTERACTION_CREATE'] = self._do_invokation
-        else:
-            await self.client.wait_for('connect')
+    async def _on_shard_connect(self, shard_id):
+        self.client._AutoShardedClient__shards[shard_id].ws._discord_parsers['INTERACTION_CREATE'] = self._do_invokation
+        self.active_shard_count += 1
+        if self.active_shard_count >= self.client.shard_count:
+            self.registered_global_commands = await self.fetch_global_commands()
+            self.is_ready = True
+            await self._activate_event('ready')
+    
+    async def _on_connect(self):
+        if not isinstance(self.client, AutoShardedClient):
             self.client.ws._discord_parsers['INTERACTION_CREATE'] = self._do_invokation
-        self.is_ready = True
-        self.client.loop.create_task(self._activate_event('ready'))
-        self.registered_global_commands = await self.fetch_global_commands()
+            self.registered_global_commands = await self.fetch_global_commands()
+            self.is_ready = True
+            await self._activate_event('ready')
     
     def _do_invokation(self, payload):
         '''
